//==================================================================
//
//	File name	:	toolbar.js
//
//	Summary		:	ToolBar class
//
//	Ceated		:	2018/12/05
//	Written by	:	Yuji Iihara
//	Copyright	:	Softinc.
//
//==================================================================
"use strict";

(function (toolbar) {
	//==========================================================
	//
	//	Class		:	ToolBarDelimiter
	//
	//	Summary		:	Class of ToolBarDelimiter
	//
	//==========================================================
	toolbar.ToolBarDelimiter = class
	{
		//==================================================
		// constructor
		//==================================================
		constructor()
		{
			// Create element
			this.element = document.createElement("div");
			this.element.style.width = "4px";
			this.element.style.height = "20px";
			this.element.style.cssFloat = "left";
			this.tabIndex = -1;
			
			var oSpan = document.createElement("span");
			oSpan.className = "v-line-inset";
			oSpan.style.height = "18px";
			oSpan.style.margin = "1px";
			
			this.element.appendChild(oSpan);
		}
		
		//==================================================
		//	Delete DOM element
		//==================================================
		destroy()
		{
			this.element.parentNode.removeChild(this.element);
		}
		
		//==================================================
		//	Set parent class
		//==================================================
		setParent(oParent)
		{
			return;
		}
		
		//==================================================
		//	Enable this
		//==================================================
		enable(bParent)
		{
			return;
		}
		
		//==================================================
		//	Disable this
		//==================================================
		disable(bParent)
		{
			return;
		}
	}
	
	
	//==========================================================
	//
	//	Class		:	ToolBar
	//
	//	Summary		:	Class of toolbar
	//
	//==========================================================
	toolbar.ToolBar = class extends jaswin.Control
	{
		//==================================================
		// constructor
		//==================================================
		constructor()
		{
			// Base class
			let oRect = new jaswin.FixedRect(jaswin.ANCHOR_LEFT, jaswin.ANCHOR_TOP, 0, 0, 0, 0);
			super(false, "ToolBar", false, oRect, true, -1);
			
			// Set properties
			this.controls = new Array();		// Controls on this toolbar[Array of classes]
			
			// Create element
			this.element = document.createElement("div");
			this.element.className = "toolbar";
		}
		
		//==================================================
		//	Delete DOM element
		//==================================================
		destroy()
		{
			let iCounter;
			for(iCounter = 0; iCounter < this.controls.length; iCounter++)
				this.controls[iCounter].destroy();
			
			this.element.parentNode.removeChild(this.element);
		}
		
		//==================================================
		//	Set parent class
		//==================================================
		setParent(oParent)
		{
			if((typeof oParent != "object")
			|| (!oParent instanceof jaswin.BaseWindow))
				throw new jaswin.JaswinError(jaswin.ERR_ALERT,
											jaswin.formatMessage(jaswin.ALERT_TYPE_PARENT, ""),
											"toolbar.js", "jaswin.toolbar.ToolBar.setParent");
			
			this.parent = oParent;
			
			let iCounter;
			for(iCounter = 0; iCounter < this.controls.length; iCounter++)
				this.controls[iCounter].setParent(this);
		}
		
		//==================================================
		//	Add control to this tool bar
		//==================================================
		addControl(oControl)
		{
			if(typeof oControl != "object")
				throw new jaswin.JaswinError(jaswin.ERR_ALERT, jaswin.ALERT_TYPE_CONTROL,
											"toolbar.js", "jaswin.toolbar.ToolBar.addControl");
			
			if((!oControl instanceof jaswin.button.Button)
			&& (!oControl instanceof jaswin.checkbox.CheckBox)
			&& (!oControl instanceof jaswin.list.ComboBox)
			&& (!oControl instanceof toolbar.ToolBarDelimiter))
				throw new jaswin.JaswinError(jaswin.ERR_ALERT, jaswin.ALERT_TYPE_CONTROL,
											"toolbar.js", "jaswin.toolbar.ToolBar.addControl");
			
			oControl.element.style.position = "relative";
			oControl.element.style.cssFloat = "left";
			oControl.element.style.left = "";
			oControl.element.style.top = "";
			
			if(oControl.tabIndex)
			{
				oControl.tabIndex = -1;
				if(oControl.focusElement)
					oControl.focusElement.tabIndex = -1;
			}
			
			this.element.appendChild(oControl.element);
			if(this.parent)
				oControl.setParent(this);
			this.controls.push(oControl);
		}
		
		//==================================================
		//	Add label to this tool bar
		//==================================================
		addLabel(sLabel)
		{
			if(typeof sLabel != "string")
				throw new jaswin.JaswinError(jaswin.ERR_ALERT,
											jaswin.formatMessage(jaswin.ALERT_TYPE_LABEL, ""),
											"toolbar.js", "jaswin.toolbar.ToolBar.addLabel");
			
			let oSpan = document.createElement("span");
			oSpan.className = "label";
			oSpan.style.position = "relative";
			oSpan.style.cssFloat = "left";
			oSpan.style.lineHeight = "20px";
			oSpan.style.paddingLeft = "2px";
			oSpan.style.paddingRight = "2px";
			oSpan.innerHTML = sLabel;
			
			this.element.appendChild(oSpan);
		}
	}
	
}(jaswin.toolbar = jaswin.toolbar || {}));
